| Title: | Sokoban Game |
|---|---|
| Description: | Interactively play a game of sokoban ,which has nine game levels.Sokoban is a type of transport puzzle, in which the player pushes boxes or crates around in a warehouse, trying to get them to storage locations. |
| Authors: | Zhaoliang He <[email protected]>, Linsui Deng <[email protected]>, Kaiwen Tan <[email protected]> |
| Maintainer: | Zhaoliang He <[email protected]> |
| License: | GPL |
| Version: | 0.1.0 |
| Built: | 2026-05-25 07:26:03 UTC |
| Source: | https://github.com/cran/sokoban |
Interactively play a game of sokoban ,which has nine game levels. Sokoban is a type of transport puzzle, in which the player pushes boxes or crates around in a warehouse, trying to get them to storage locations.
sokoban()sokoban()
display='windows' makes use of the getGraphicsEvent function, which currently only works on Windows.
Zhaoliang He <[email protected]>, Linsui Deng <[email protected]>, Kaiwen Tan <[email protected]>
sokoban()sokoban()